@@ -687,7 +687,6 @@ static inline void create_list_view(FmStandardView* fv, GList* sels)
                                         FM_FOLDER_MODEL_COL_NAME);
     }
 
-    gtk_tree_view_set_reorderable(GTK_TREE_VIEW(fv->view), TRUE);
     gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(fv->view), TRUE);
     gtk_tree_view_set_rubber_banding(GTK_TREE_VIEW(fv->view), TRUE);
     exo_tree_view_set_single_click((ExoTreeView*)fv->view, fm_config->single_click);
@@ -1386,6 +1385,11 @@ gboolean _fm_standard_view_set_columns(FmFolderView* fv, const GSList* cols)
             old_cols[i].info = NULL; /* don't try to use it again */
             /* TODO: update all other data - width for example */
         }
+        else if(!fm_folder_model_col_get_name(FM_FOLDER_MODEL_COL_NAME))
+            /* workaround for case when there is no model init yet, the most
+               probably bug #3596550 is about this (it creates column with
+               empty title), can g_return_val_if_fail() not fail somehow? */
+            continue;
         else
         {
             /* if not found then append new one */
