@@ -165,6 +165,24 @@ static gboolean fm_file_info_job_run(FmJob* fmjob)
             gf = fm_path_to_gfile(path);
             if(!_fm_file_info_job_get_info_for_gfile(fmjob, fi, gf, &err))
             {
+              if(err->domain == G_IO_ERROR && err->code == G_IO_ERROR_NOT_MOUNTED)
+              {
+                GFileInfo *inf;
+                /* location by link isn't mounted; unfortunately we cannot
+                   launch a target if we don't know what kind of target we
+                   have; lets make a simplest directory-kind GFIleInfo */
+                /* FIXME: this may be dirty a bit */
+                g_error_free(err);
+                err = NULL;
+                inf = g_file_info_new();
+                g_file_info_set_file_type(inf, G_FILE_TYPE_DIRECTORY);
+                g_file_info_set_name(inf, fm_path_get_basename(path));
+                g_file_info_set_display_name(inf, fm_path_get_basename(path));
+                fm_file_info_set_from_gfileinfo(fi, inf);
+                g_object_unref(inf);
+              }
+              else
+              {
                 FmJobErrorAction act = fm_job_emit_error(fmjob, err, FM_JOB_ERROR_MILD);
                 g_error_free(err);
                 err = NULL;
@@ -175,6 +193,7 @@ static gboolean fm_file_info_job_run(FmJob* fmjob)
                 }
 
                 fm_file_info_list_delete_link(job->file_infos, l); /* also calls unref */
+              }
             }
             g_object_unref(gf);
         }
